==> react-disqus-counter-0.0.6.tgz: package/lib/__tests__/ReactDisqusCounter.js <==
'use strict';

var _ava = require('ava');

var _ava2 = _interopRequireDefault(_ava);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactAddonsTestUtils = require('react-addons-test-utils');

var _expect = require('expect');

var _expect2 = _interopRequireDefault(_expect);

var _expectJsx = require('expect-jsx');

var _expectJsx2 = _interopRequireDefault(_expectJsx);

var _ReactDisqusCounter = require('../ReactDisqusCounter');

var _ReactDisqusCounter2 = _interopRequireDefault(_ReactDisqusCounter);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_expect2.default.extend(_expectJsx2.default);

(0, _ava2.default)('Should render non-link element with no default content', function (t) {
  var renderer = (0, _reactAddonsTestUtils.createRenderer)();
  renderer.render(_react2.default.createElement(_ReactDisqusCounter2.default, { shortname: 'test', url: '/' }));
  (0, _expect2.default)(renderer.getRenderOutput()).toEqualJSX(_react2.default.createElement('span', { className: ['disqus-comment-count'], 'data-disqus-url': '/' }));
});

(0, _ava2.default)('Should render non-link element with content', function (t) {
  var renderer = (0, _reactAddonsTestUtils.createRenderer)();
  renderer.render(_react2.default.createElement(_ReactDisqusCounter2.default, { shortname: 'test', url: '/', content: 'My Content' }));
  (0, _expect2.default)(renderer.getRenderOutput()).toEqualJSX(_react2.default.createElement(
    'span',
    { className: ['disqus-comment-count'], 'data-disqus-url': '/' },
    'My Content'
  ));
});

(0, _ava2.default)('Should render link element with no default content', function (t) {
  var renderer = (0, _reactAddonsTestUtils.createRenderer)();
  renderer.render(_react2.default.createElement(_ReactDisqusCounter2.default, { shortname: 'test', url: '/', isLink: true }));
  (0, _expect2.default)(renderer.getRenderOutput()).toEqualJSX(_react2.default.createElement('a', { href: '/#disqus_thread' }));
});

(0, _ava2.default)('Should render link element with content', function (t) {
  var renderer = (0, _reactAddonsTestUtils.createRenderer)();
  renderer.render(_react2.default.createElement(_ReactDisqusCounter2.default, { shortname: 'test', url: '/', isLink: true, content: 'My Content' }));
  (0, _expect2.default)(renderer.getRenderOutput()).toEqualJSX(_react2.default.createElement(
    'a',
    { href: '/#disqus_thread' },
    'My Content'
  ));
});

==> react-disqus-counter-0.0.9.tgz: package/lib/__tests__/ReactDisqusCounter.js <==
'use strict';

var _ava = require('ava');

var _ava2 = _interopRequireDefault(_ava);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactAddonsTestUtils = require('react-addons-test-utils');

var _expect = require('expect');

var _expect2 = _interopRequireDefault(_expect);

var _expectJsx = require('expect-jsx');

var _expectJsx2 = _interopRequireDefault(_expectJsx);

var _ReactDisqusCounter = require('../ReactDisqusCounter');

var _ReactDisqusCounter2 = _interopRequireDefault(_ReactDisqusCounter);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_expect2.default.extend(_expectJsx2.default);

(0, _ava2.default)('Should render non-link element with no default content', function (t) {
  var renderer = (0, _reactAddonsTestUtils.createRenderer)();
  renderer.render(_react2.default.createElement(_ReactDisqusCounter2.default, { shortname: 'test', url: '/' }));
  (0, _expect2.default)(renderer.getRenderOutput()).toEqualJSX(_react2.default.createElement('span', { className: ['disqus-comment-count'], 'data-disqus-url': '/' }));
});

(0, _ava2.default)('Should render non-link element with content', function (t) {
  var renderer = (0, _reactAddonsTestUtils.createRenderer)();
  renderer.render(_react2.default.createElement(
    _ReactDisqusCounter2.default,
    { shortname: 'test', url: '/' },
    'My Content'
  ));
  (0, _expect2.default)(renderer.getRenderOutput()).toEqualJSX(_react2.default.createElement(
    'span',
    { className: ['disqus-comment-count'], 'data-disqus-url': '/' },
    'My Content'
  ));
});

(0, _ava2.default)('Should render link element with no default content', function (t) {
  var renderer = (0, _reactAddonsTestUtils.createRenderer)();
  renderer.render(_react2.default.createElement(_ReactDisqusCounter2.default, { shortname: 'test', url: '/', isLink: true }));
  (0, _expect2.default)(renderer.getRenderOutput()).toEqualJSX(_react2.default.createElement('a', { href: '/#disqus_thread' }));
});

(0, _ava2.default)('Should render link element with content', function (t) {
  var renderer = (0, _reactAddonsTestUtils.createRenderer)();
  renderer.render(_react2.default.createElement(
    _ReactDisqusCounter2.default,
    { shortname: 'test', url: '/', isLink: true },
    'My Content'
  ));
  (0, _expect2.default)(renderer.getRenderOutput()).toEqualJSX(_react2.default.createElement(
    'a',
    { href: '/#disqus_thread' },
    'My Content'
  ));
});
